@@ -2,12 +2,13 @@
 
 require 5;
 use 5.8.0;
-package Text::Unidecode;  # Time-stamp: "2014-07-25 03:31:41 MDT sburke@cpan.org"
+package Text::Unidecode;
+$Last_Modified =' Time-stamp: "2015-10-16 02:39:22 MDT sburke@cpan.org"';
 use utf8;
 use strict;
 use integer; # vroom vroom!
-use vars qw($VERSION @ISA @EXPORT @Char $UNKNOWN $NULLMAP $TABLE_SIZE);
-$VERSION = '1.20_01';
+use vars qw($VERSION @ISA @EXPORT @Char $UNKNOWN $NULLMAP $TABLE_SIZE $Last_Modified);
+$VERSION = '1.25_01';
 require Exporter;
 @ISA = ('Exporter');
 @EXPORT = ('unidecode');
@@ -44,6 +45,12 @@ sub unidecode {
 
   foreach my $n (@_) {
     next unless defined $n;    
+
+    # Shut up potentially fatal warnings about UTF-16 surrogate
+    # characters when running under perl -w
+    # This is per https://rt.cpan.org/Ticket/Display.html?id=97456
+    no warnings 'utf8';
+
     $n =~ s~([^\x00-\x7f])~${$Char[ord($1)>>8]||t($1)}[ord($1)&255]~egs;
   }
   # That means:
@@ -94,8 +101,8 @@ sub unidecode {
   #       use other delimiters, such as "s!!!" and "s{}{}", 
   #  I didn't do it for sake of obscurity. I think it's just to
   #  keep my editor's syntax highlighter from crashing,
-  #  which was a problem with s///
-  #
+  #  which was a problem with s/// when the insides are as gory
+  #  as we have here.
 
   return unless defined wantarray; # void context
   return @_ if wantarray;  # normal list context -- return the copies
@@ -192,7 +199,7 @@ sub load_bank {
   my($banknum) = @_;  # just as an integer value
 
   DEBUG and printf
-      "# Eval-loading %s::x%02x ...\n",
+      "# Eval-loading %s::x%02x ...\n";
 
   $eval_loaded_okay = 0;
   my $code = 
@@ -393,7 +400,7 @@ be better transliterated as "D", I I<may> well make that change.
 
 Unfortunately, there are many characters that Unidecode doesn't know a
 transliteration for.  This is generally because the character has been
-added since I last revised the Unidecode data tables.  I'm always
+added since I last revised the Unidecode data tables.  I'm I<always>
 catching up!
 
 =back
@@ -521,6 +528,10 @@ lot like: KAK BAC 3OBYT
 
 "丫二十一" is four Chinese characters that should look like: C<Y=+->
 
+=item *
+
+"Ｈｅｌｌｏ" is five characters that should look like: Hello
+
 =back
 
 If all of those come out right, your Pod viewing setup is working
@@ -603,6 +614,8 @@ If you know that the text you're handling is probably in German, and
 you want to apply the "umlaut becomes -e" rule, here's how to do it
 for yourself (and then use Unidecode as I<the fallback> afterwards):
 
+  use utf8;  # <-- probably necessary.
+
   our( %German_Characters ) = qw(
    Ä AE   ä ae
    Ö OE   ö oe
@@ -689,8 +702,45 @@ Abhijit Menon-Sen, Mark-Jason Dominus, Joe Johnston,
 Conrad Heiney, fileformat.info,
 Philip Newton, 唐鳳, Tomaž Šolc, Mike Doherty, JT Smith and the
 MadMongers, Arden Ogg, Craig Copris,
-and I<many> other pals in Unicode's behind-the-scenes F5
-tornado underlying its code.
+David Cusimano, Brendan Byrd,
+and
+I<many>
+other pals who helped with the ideas or values for Unidecode's
+transliterations, or in the secret F5 tornado in its Perl code.
+
+
+
+=head1 PORTS
+
+Some wonderful people have ported Unidecode to other languages!
+
+=over
+
+=item *
+
+Python: L<https://pypi.python.org/pypi/Unidecode>
+
+=item *
+
+PHP: L<https://github.com/silverstripe-labs/silverstripe-unidecode>
+
+=item *
+
+Ruby: L<http://www.rubydoc.info/gems/unidecode/1.0.0/frames>
+
+=item *
+
+JavaScript: L<https://www.npmjs.org/package/unidecode>
+
+=item *
+
+Java: L<https://github.com/xuender/unidecode>
+
+=back
+
+I can't vouch for the details of each port, but these are clever
+people, so I'm sure they did a fine job.
+
 
 =head1 SEE ALSO
 
@@ -698,6 +748,10 @@ An article I wrote for I<The Perl Journal> about
 Unidecode:  L<http://interglacial.com/tpj/22/>
 (B<READ IT!>)
 
+Tom Christiansen's
+I<Perl Unicode Cookbook>,
+L<http://www.perl.com/pub/2012/04/perlunicook-standard-preamble.html>
+
 Unicode Consortium: L<http://www.unicode.org/>
 
 Searchable Unihan database:
@@ -717,7 +771,7 @@ Books).>  ISBN: 0658009109
 
 =head1 LICENSE
 
-Copyright (c) 2001, 2014 Sean M. Burke.
+Copyright (c) 2001, 2014, 2015 Sean M. Burke.
 
 Unidecode is distributed under the Perl Artistic License
 ( L<perlartistic> ), namely:
@@ -741,7 +795,7 @@ Unicode Consortium.
 
 =head1 AUTHOR
 
-Sean M. Burke C<sburke@cpan.org>
+Your pal, Sean M. Burke C<sburke@cpan.org>
 
 =cut
 
